@@ -77,43 +77,46 @@ def read_values_from_array(query_columns_description: list, dis: DataInputStream
         if isPresent == 0:
             value_array.append(None)
             continue
-
-        if dtype == "LONG":
-            value_array.append(dis.read_long())
-        elif dtype == "DATE":
-            epoch_days = dis.read_long() * 86400
-            date = datetime.fromtimestamp(epoch_days)
-            value_array.append(date.strftime("%Y-%m-%d"))
-        elif dtype == "DATETIME":
-            epoch_days = dis.read_long() / 1000_000
-            date_time = datetime.fromtimestamp(epoch_days)
-            value_array.append(date_time.strftime("%Y-%m-%d %H:%M:%S"))
-        elif dtype == "STRING":
-            value_array.append(dis.read_utf().decode())
-        elif dtype == "INT":
-            value_array.append(dis.read_int())
-        elif dtype == "DOUBLE":
-            value_array.append(dis.read_double())
-        elif dtype == "BINARY":
-            value_array.append(dis.read_utf())
-        elif dtype == "FLOAT":
-            value_array.append(dis.read_float())
-        elif dtype == "CHAR":
-            value_array.append(dis.read_char())
-        elif dtype == "BOOLEAN":
-            value_array.append(dis.read_boolean())
-        elif dtype == "SHORT":
-            value_array.append(dis.read_short())
-        elif dtype == "BYTE":
-            value_array.append(dis.read_byte())
-        elif dtype == "INT96":
-            julian_day = dis.read_int()
-            time = dis.read_long()
-            date_time = datetime.fromtimestamp((julian_day - 2440588) * 86400)
-            date_time_with_nanos = date_time + timedelta(microseconds=(time/1000))
-            value_array.append(date_time_with_nanos.strftime("%Y-%m-%d %H:%M:%S"))
-        elif dtype == "INTEGER":
-            value_array.append(dis.read_int())
+        try:
+            if dtype == "LONG":
+                value_array.append(dis.read_long())
+            elif dtype == "DATE":
+                epoch_days = dis.read_long() * 86400
+                date = datetime.fromtimestamp(epoch_days)
+                value_array.append(date.strftime("%Y-%m-%d"))
+            elif dtype == "DATETIME":
+                epoch_days = dis.read_long() / 1000_000
+                date_time = datetime.fromtimestamp(epoch_days)
+                value_array.append(date_time.strftime("%Y-%m-%d %H:%M:%S"))
+            elif dtype == "STRING":
+                value_array.append(dis.read_utf().decode())
+            elif dtype == "INT":
+                value_array.append(dis.read_int())
+            elif dtype == "DOUBLE":
+                value_array.append(dis.read_double())
+            elif dtype == "BINARY":
+                value_array.append(dis.read_utf())
+            elif dtype == "FLOAT":
+                value_array.append(dis.read_float())
+            elif dtype == "CHAR":
+                value_array.append(dis.read_char())
+            elif dtype == "BOOLEAN":
+                value_array.append(dis.read_boolean())
+            elif dtype == "SHORT":
+                value_array.append(dis.read_short())
+            elif dtype == "BYTE":
+                value_array.append(dis.read_byte())
+            elif dtype == "INT96":
+                julian_day = dis.read_int()
+                time = dis.read_long()
+                date_time = datetime.fromtimestamp((julian_day - 2440588) * 86400)
+                date_time_with_nanos = date_time + timedelta(microseconds=(time / 1000))
+                value_array.append(date_time_with_nanos.strftime("%Y-%m-%d %H:%M:%S"))
+            elif dtype == "INTEGER":
+                value_array.append(dis.read_int())
+        except Exception as e:
+            _logger.error(e)
+            value_array.append('Failed to parse.')
 
     return value_array
 
